==> pf4-component-mapper-3.4.1.tgz: package/esm/select/select.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from '../form-group/form-group';
import DataDrivenSelect from './select/select';

var Select = function Select(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"]);

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(DataDrivenSelect, _extends({}, input, rest, {
    isDisabled: isDisabled || isReadOnly
  })));
};

Select.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};
export default Select;
export var InternalSelect = DataDrivenSelect;

==> pf4-component-mapper-3.23.0.tgz: package/esm/select/select.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"];
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from '../form-group/form-group';
import DataDrivenSelect from './select/select';

var Select = function Select(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(DataDrivenSelect, _extends({}, input, rest, {
    isDisabled: isDisabled || isReadOnly
  })));
};

Select.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};
export default Select;
export var InternalSelect = DataDrivenSelect;
